<?php
namespace Service\Mail;

use Service\Mail\BuildMail;

class IndicatorMail {

    private $buildMail;
    private $baseDir = '';

    public function __construct(BuildMail $buildMail){
        $this->buildMail = $buildMail;
        $this->baseDir = __DIR__.DIRECTORY_SEPARATOR.'EmailTemplates'.DIRECTORY_SEPARATOR;
    }

    public function sendMessageMail($to, $senderName, $messageUser, $date, $indicatorName, $indicatorContent, $messageType){
        $subject = "Indicator: {$indicatorName}";
        $head = $this->buildHeadMessage($indicatorName, $messageUser, 'indicator_mail_head.html');
        $tail = $this->buildTailMessage($date, $senderName, 'indicator_mail_tail.html');
        if($messageType == 'grid'){
            $text = $this->buildBodyPdfMessage($indicatorContent, 'indicator_mail_body_pdf.html');
        } else{
            $text = $this->buildBodyImageMessage($indicatorContent, 'indicator_mail_body_image.html');
        }

        $message = $this->buildMail->setMessageMail($head.$text.$tail);
        $this->buildMail->sendHtml($to, $subject, $message, $senderName);
    }

    public function buildHeadMessage($indicatorName, $message){
        $replacedContents = $this->buildMail->setMessage('indicator_mail_head.html');
        $replacedContents = str_replace('%indicatorName%', $indicatorName, $replacedContents);
        $replacedContents = str_replace('%message%', $message, $replacedContents);
        return $replacedContents;
    }

    public function buildTailMessage($date, $fromName){
        $replacedContents = $this->buildMail->setMessage('indicator_mail_tail.html');
        $replacedContents = str_replace('%data%', $date, $replacedContents);
        $replacedContents = str_replace('%nameSender%', $fromName, $replacedContents);
        return $replacedContents;
    }

    public function buildBodyImageMessage($indicatorContent){
        $replacedContents = $this->buildMail->setMessage('indicator_mail_body_image.html');
        $replacedContents = str_replace('%indicatorContent%', $indicatorContent, $replacedContents);
        return $replacedContents;
    }

    public function buildBodyPdfMessage($indicatorContent){
        $replacedContents = $this->buildMail->setMessage('indicator_mail_body_pdf.html');
        $replacedContents = str_replace('%indicatorContent%', $indicatorContent, $replacedContents);
        return $replacedContents;
    }
}